@@ -11,6 +11,8 @@ import logging
 import numpy as np
 import pandas as pd
 
+from flex.extensions.tabledata import JSONTableExtension
+
 from ..persistence import IPersist
 from ..util import air2vac, vac2air
 
@@ -42,7 +44,7 @@ class LineList(IPersist):
     citation_info = ""
 
     @staticmethod
-    def parse_line_error(error_flags, values):
+    def parse_line_error(error_flags, values=None):
         """Transform Line Error flags into relative error values
 
         Parameters
@@ -57,6 +59,9 @@ class LineList(IPersist):
         errors : list(float)
             relative errors for each line
         """
+        if values is None:
+            values = np.ones(len(error_flags))
+
         nist = {
             "AAA": 0.003,
             "AA": 0.01,
@@ -144,7 +149,9 @@ class LineList(IPersist):
 
     def __init__(self, linedata=None, lineformat="short", medium=None, **kwargs):
         if linedata is None or len(linedata) == 0:
-            if "atomic" in kwargs.keys():
+            if isinstance(linedata, pd.DataFrame):
+                linedata = pd.DataFrame(data=linedata, columns=self._base_columns)
+            elif "atomic" in kwargs.keys():
                 # everything is in the kwargs (usually by loading from old SME file)
                 linedata, lineformat = LineList.from_IDL_SME(**kwargs)
             else:
@@ -168,7 +175,7 @@ class LineList(IPersist):
 
                 if "ionization" in kwargs.keys():
                     linedata["ionization"] = kwargs["ionization"]
-                elif "ionization" not in linedata:
+                elif "ionization" not in linedata and "species" in linedata:
                     linedata["ionization"] = np.array(
                         [int(s[-1]) for s in linedata["species"]], dtype=float
                     )
@@ -186,8 +193,14 @@ class LineList(IPersist):
         self.lineformat = lineformat
         #:pandas.DataFrame: DataFrame that contains all the data
         self._lines = linedata  # should have all the fields (20)
-        self._medium = medium
+        if medium in ["air", "vac", None]:
+            self._medium = medium
+        else:
+            raise ValueError(
+                f"Medium not recognized, expected one of ['air', 'vac'] , but got {medium} instead."
+            )
 
+        self.citation_info = ""
         if "citation_info" in kwargs.keys():
             self.citation_info = kwargs["citation_info"]
 
@@ -197,11 +210,18 @@ class LineList(IPersist):
     def __str__(self):
         return str(self._lines)
 
+    def __repr__(self):
+        return self.__str__()
+
     def __iter__(self):
         return self._lines.itertuples(index=False)
 
     def __getitem__(self, index):
         if isinstance(index, (list, str)):
+            if len(index) == 0:
+                return LineList(
+                    self._lines.iloc[[]], lineformat=self.lineformat, medium=self.medium
+                )
             values = self._lines[index].values
             if index in self.string_columns:
                 values = values.astype(str)
@@ -210,13 +230,19 @@ class LineList(IPersist):
             if isinstance(index, int):
                 index = slice(index, index + 1)
             # just pass on a subsection of the linelist data, but keep it a linelist object
-            return LineList(self._lines.iloc[index], self.lineformat)
+            return LineList(
+                self._lines.iloc[index], self.lineformat, medium=self.medium
+            )
 
     def __getattribute__(self, name):
         if name[0] != "_" and name not in dir(self):
             return self._lines[name].values
         return super().__getattribute__(name)
 
+    @property
+    def columns(self):
+        return self._lines.columns
+
     @property
     def medium(self):
         return self._medium
@@ -341,7 +367,22 @@ class LineList(IPersist):
         }
         self._lines = self._lines.append([linedata])
 
-    def _save(self, file, folder="linelist"):
+    def _save(self):
+        header = {
+            "lineformat": self.lineformat,
+            "medium": self.medium,
+            "citation_info": self.citation_info,
+        }
+        data = self._lines
+        ext = JSONTableExtension(header, data)
+        return ext
+
+    @classmethod
+    def _load(cls, ext: JSONTableExtension):
+        ll = cls(ext.data, **ext.header)
+        return ll
+
+    def _save_v1(self, file, folder="linelist"):
         if folder != "" and folder[-1] != "/":
             folder = folder + "/"
 
@@ -362,7 +403,7 @@ class LineList(IPersist):
         file.writestr(f"{folder}data.json", linedata)
 
     @staticmethod
-    def _load(file, names, folder=""):
+    def _load_v1(file, names, folder=""):
         for name in names:
             if name.endswith("info.json"):
                 info = file.read(name)
